==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/modules/payment/hpidl.lang.inc.php <==
<?php
/*
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
*/

$t_language_text_section_content_array = array
(
    'MODULE_PAYMENT_HPIDL_TEXT_ERROR' => 'Bei der Zahlungsverarbeitung ist in Fehler aufgetreten.',
	'MODULE_PAYMENT_HPIDL_TEXT_TITLE' => 'IDeal',
	'MODULE_PAYMENT_HPIDL_TEXT_DESC' => 'IDeal &uuml;ber heidelpay GmbH',
	'MODULE_PAYMENT_HPIDL_TEXT_INFO' => '',
	'MODULE_PAYMENT_HPIDL_TEST_ACCOUNT_TITLE' => 'Test Account',
	'MODULE_PAYMENT_HPIDL_TEST_ACCOUNT_DESC' => 'Im Sandbox Mode sollen folgende E-Mail-Accounts testen können. (Komma getrennt)',
	'MODULE_PAYMENT_HPIDL_PROCESSED_STATUS_ID_TITLE' => 'Bestellstatus - Erfolgreich',
	'MODULE_PAYMENT_HPIDL_PROCESSED_STATUS_ID_DESC' => 'Dieser Status wird gesetzt wenn die Bezahlung erfolgreich war.',
	'MODULE_PAYMENT_HPIDL_PENDING_STATUS_ID_TITLE' => 'Bestellstatus - Wartend',
	'MODULE_PAYMENT_HPIDL_PENDING_STATUS_ID_DESC' => 'Dieser Status wird gesetzt wenn die der Kunde auf einem Fremdsystem ist.',
	'MODULE_PAYMENT_HPIDL_CANCELED_STATUS_ID_TITLE' => 'Bestellstatus - Abbruch',
	'MODULE_PAYMENT_HPIDL_CANCELED_STATUS_ID_DESC' => 'Dieser Status wird gesetzt wenn die Bezahlung abgebrochen wurde.',
	'MODULE_PAYMENT_HPIDL_STATUS_TITLE' => 'Modul aktivieren',
	'MODULE_PAYMENT_HPIDL_STATUS_DESC' => 'Möchten Sie das Modul aktivieren?',
	'MODULE_PAYMENT_HPIDL_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_HPIDL_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_HPIDL_ZONE_TITLE' => 'Zahlungszone',
	'MODULE_PAYMENT_HPIDL_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_HPIDL_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_HPIDL_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_HPIDL_WRONG_COUNTRY' => 'Diese Zahlart steht für dieses Land nicht zur Verfügung.'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/modules/payment/hpidl.lang.inc.php <==
<?php
/*
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
*/

$t_language_text_section_content_array = array
(
    'MODULE_PAYMENT_HPIDL_TEXT_ERROR' => 'Bei der Zahlungsverarbeitung ist in Fehler aufgetreten.',
	'MODULE_PAYMENT_HPIDL_TEXT_TITLE' => 'IDeal',
	'MODULE_PAYMENT_HPIDL_TEXT_DESC' => 'IDeal &uuml;ber heidelpay GmbH',
	'MODULE_PAYMENT_HPIDL_TEXT_INFO' => '',
	'MODULE_PAYMENT_HPIDL_TEST_ACCOUNT_TITLE' => 'Test Account',
	'MODULE_PAYMENT_HPIDL_TEST_ACCOUNT_DESC' => 'Im Sandbox Mode sollen folgende E-Mail-Accounts testen können. (Komma getrennt)',
	'MODULE_PAYMENT_HPIDL_PROCESSED_STATUS_ID_TITLE' => 'Bestellstatus - Erfolgreich',
	'MODULE_PAYMENT_HPIDL_PROCESSED_STATUS_ID_DESC' => 'Dieser Status wird gesetzt wenn die Bezahlung erfolgreich war.',
	'MODULE_PAYMENT_HPIDL_PENDING_STATUS_ID_TITLE' => 'Bestellstatus - Wartend',
	'MODULE_PAYMENT_HPIDL_PENDING_STATUS_ID_DESC' => 'Dieser Status wird gesetzt wenn die der Kunde auf einem Fremdsystem ist.',
	'MODULE_PAYMENT_HPIDL_CANCELED_STATUS_ID_TITLE' => 'Bestellstatus - Abbruch',
	'MODULE_PAYMENT_HPIDL_CANCELED_STATUS_ID_DESC' => 'Dieser Status wird gesetzt wenn die Bezahlung abgebrochen wurde.',
	'MODULE_PAYMENT_HPIDL_STATUS_TITLE' => 'Modul aktivieren',
	'MODULE_PAYMENT_HPIDL_STATUS_DESC' => 'Möchtest du das Modul aktivieren?',
	'MODULE_PAYMENT_HPIDL_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_HPIDL_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_HPIDL_ZONE_TITLE' => 'Zahlungszone',
	'MODULE_PAYMENT_HPIDL_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_HPIDL_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_HPIDL_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_HPIDL_WRONG_COUNTRY' => 'Diese Zahlart steht für dieses Land nicht zur Verfügung.'
);
